@@ -6,60 +6,60 @@
 #' plotting of equivalent dose distributions.
 #'
 #' \tabular{ll}{ Package: \tab Luminescence\cr Type: \tab Package\cr Version:
-#' \tab 0.6.2 \cr Date: \tab 2016-09-01 \cr License: \tab GPL-3\cr }
+#' \tab 0.7.0 \cr Date: \tab 2016-12-XX \cr License: \tab GPL-3\cr }
 #'
 #' @name Luminescence-package
 #' @aliases Luminescence-package Luminescence
 #' @docType package
-#' @author \bold{Authors} (alphabetic order)
+#' @author \bold{Full list of authors and contributors} (alphabetic order)
 #'
 #' \tabular{ll}{
 #' Christoph Burow \tab University of Cologne, Germany \cr
+#' Claire Christophe \tab IRAMAT-CRP2A, Universite Bordeaux Montaigne, France \cr
 #' Michael Dietze \tab GFZ Helmholtz Centre Potsdam, Germany \cr
 #' Julie Durcan \tab University of Oxford, United Kingdom \cr
 #' Manfred Fischer\tab University of Bayreuth, Germany \cr
 #' Margret C. Fuchs \tab Helmholtz-Zentrum Dresden-Rossendorf, Helmholtz-Institute Freiberg for Resource Technology,
 #' Freiberg, Germany \cr
 #' Johannes Friedrich \tab University of Bayreuth, Germany \cr
-#' Georgina King \tab University of Cologne, Germany \cr
+#' Guillaume Guerin \tab IRAMAT-CRP2A, Universite Bordeaux Montaigne, France \cr
+#' Georgina King \tab Institute of Geological Sciences, University of Bern, Switzerland \cr
 #' Sebastian Kreutzer \tab IRAMAT-CRP2A, Universite Bordeaux Montaigne, France \cr
 #' Norbert Mercier \tab IRAMAT-CRP2A, Universite Bordeaux Montaigne, France \cr
+#' Anne Philippe \tab  Universite de Nantes and ANJA INRIA, Rennes, France \cr
 #' Christoph Schmidt \tab University of Bayreuth, Germany \cr
-#' Rachel K. Smedley \tab Aberystwyth University, United Kingdom
-#
+#' Rachel K. Smedley \tab Aberystwyth University, United Kingdom \cr
+#' Antoine Zink \tab C2RMF, Palais du Louvre, Paris, France
 #' }
 #'
-#' \bold{Beta-Tester}
-#'
-#' Thomas Kolb, University of Bayreuth, Germany\cr
-#'
-#' \bold{Supervisor}
+#' \bold{Supervisor of the initial version in 2012}
 #'
 #' Markus Fuchs, Justus-Liebig-University Giessen, Germany\cr
 #'
 #' \bold{Support contact}
 #'
-#' \email{developers@@r-luminescence.de}\cr
+#' \email{developers@@r-luminescence.org}\cr
 #'
 #' We may further encourage the usage of our support forum. For this please
 #' visit our project website (link below).
 #'
 #' \bold{Bug reporting}
 #'
-#' \email{bugtracker@@r-luminescence.de} \cr
+#' \email{developers@@r-luminescence.org} or \cr
+#' \url{https://github.com/R-Lum/Luminescence/issues} \cr
 #'
 #' \bold{Project website}
 #'
-#' \url{http://www.r-luminescence.de}\cr
+#' \url{http://www.r-luminescence.org}\cr
 #'
 #' \bold{Project source code repository}\cr
 #' \url{https://github.com/R-Lum/Luminescence}\cr
 #'
 #' \bold{Related package projects}\cr
-#' \url{http://cran.r-project.org/package=RLumShiny}\cr
-#' \url{http://shiny.r-luminescence.de}\cr
-#' \url{http://cran.r-project.org/package=RLumModel}\cr
-#' \url{http://model.r-luminescence.de}\cr
+#' \url{https://cran.r-project.org/package=RLumShiny}\cr
+#' \url{http://shiny.r-luminescence.org}\cr
+#' \url{https://cran.r-project.org/package=RLumModel}\cr
+#' \url{http://model.r-luminescence.org}\cr
 #'
 #' \bold{Package maintainer}
 #'
@@ -70,7 +70,7 @@
 #'
 #' Cooperation and personal exchange between the developers is gratefully
 #' funded by the DFG (SCHM 3051/3-1) in the framework of the program
-#' "Scientific Networks". Project title: "Lum.Network: Ein
+#' "Scientific Networks". Project title: "RLum.Network: Ein
 #' Wissenschaftsnetzwerk zur Analyse von Lumineszenzdaten mit R" (2014-2017)
 #'
 #' @references Dietze, M., Kreutzer, S., Fuchs, M.C., Burow, C., Fischer, M.,
@@ -94,13 +94,13 @@
 #' Ancient TL 33, 16-21.
 #'
 #' @keywords package
-#' @import utils methods data.table bbmle
-#' @importFrom raster nlayers raster contour plotRGB brick
-#' @importFrom graphics plot.default frame abline mtext text lines par layout lines arrows axTicks axis barplot box boxplot contour curve grconvertX grconvertY hist legend persp points polygon rug segments title grid
-#' @importFrom grDevices adjustcolor axisTicks colorRampPalette gray.colors rgb topo.colors dev.off
-#' @importFrom stats approx as.formula complete.cases density dnorm glm lm median na.exclude na.omit nls nls.control pchisq pnorm quantile rnorm runif sd smooth smooth.spline spline t.test uniroot var weighted.mean setNames
+#' @import utils methods data.table magrittr
+#' @importFrom raster nlayers raster contour plot plotRGB brick
+#' @importFrom graphics plot plot.default frame abline mtext text lines par layout lines arrows axTicks axis barplot box boxplot contour curve grconvertX grconvertY hist legend persp points polygon rug segments title grid
+#' @importFrom grDevices adjustcolor axisTicks colorRampPalette gray.colors rgb topo.colors xy.coords dev.off
+#' @importFrom stats approx as.formula complete.cases density dnorm glm lm median na.exclude na.omit nls nls.control pchisq pnorm quantile rnorm runif sd smooth smooth.spline spline t.test uniroot var weighted.mean setNames coef confint predict update residuals
 #' @importFrom parallel parLapply makeCluster stopCluster
-#' @importFrom Rcpp evalCpp
+#' @importFrom httr GET accept_json status_code content
 #' @useDynLib Luminescence
 NULL
 
@@ -311,6 +311,29 @@ NULL
 
 
 
+#' Example portable OSL curve data for the package Luminescence
+#'
+#' A \code{list} of \code{\linkS4class{RLum.Analysis}} objects, each containing
+#' the same number of \code{\linkS4class{RLum.Data.Curve}} objects representing
+#' individual OSL, IRSL and dark count measurements of a sample.
+#'
+#' @name ExampleData.portableOSL
+#' @docType data
+#'
+#' @source \bold{ExampleData.portableOSL}
+#'
+#' \tabular{ll}{ Lab: \tab Cologne Luminescence Laboratory\cr Lab-Code: \tab
+#' - \cr Location: \tab Nievenheim/Germany\cr Material: \tab Fine grain quartz
+#' \cr Reference: \tab unpublished data }
+#'
+#' @keywords datasets
+#' @examples
+#'
+#' data(ExampleData.portableOSL, envir = environment())
+#' plot_RLum(ExampleData.portableOSL)
+#'
+NULL
+
 
 
 #' Example data for fit_LMCurve() in the package Luminescence
@@ -605,3 +628,101 @@ NULL
 #'
 #' @name ExampleData.DeValues
 NULL
+
+
+#' Example data for feldspar fading measurements
+#'
+#' Example data set for fading measurements of the IR50, IR100, IR150 and
+#' IR225 feldspar signals of sample UNIL/NB123. It further contains regular equivalent dose
+#' measurement data of the same sample, which can be used to apply a
+#' fading correction to.
+#'
+#'
+#' @format A \code{\link{list}} with two elements, each containing a further
+#' \code{\link{list}} of \code{\link{data.frame}}s containing the data
+#' on the fading and equivalent dose measurements:
+#'
+#' \describe{
+#'
+#' \code{$fading.data}: A named \code{\link{list}} of \code{\link{data.frame}}s,
+#' each having three named columns (\code{LxTx, LxTx.error, timeSinceIrradiation}).\cr
+#' \code{..$IR50}: Fading data of the IR50 signal.\cr
+#' \code{..$IR100}: Fading data of the IR100 signal.\cr
+#' \code{..$IR150}: Fading data of the IR150 signal.\cr
+#' \code{..$IR225}: Fading data of the IR225 signal.\cr
+#' \cr\cr
+#'
+#' \code{$equivalentDose.data}: A named of \code{\link{data.frame}}s,
+#' each having three named columns (\code{dose, LxTx, LxTx.error}).\cr
+#' \code{..$IR50}: Equivalent dose measurement data of the IR50 signal.\cr
+#' \code{..$IR100}: Equivalent dose measurement data of the IR100 signal.\cr
+#' \code{..$IR150}: Equivalent dose measurement data of the IR150 signal.\cr
+#' \code{..$IR225}: Equivalent dose measurement data of the IR225 signal.\cr
+#' \cr\cr
+#'
+#' }
+#'
+#' @source
+#'
+#' These data were kindly provided by Georgina King. Detailed information
+#' on the sample UNIL/NB123 can be found in the reference given below. The raw
+#' data can be found in the accompanying supplementary information.
+#'
+#' @references
+#'
+#' King, G.E., Herman, F., Lambert, R., Valla, P.G., Guralnik, B., 2016.
+#' Multi-OSL-thermochronometry of feldspar. Quaternary Geochronology 33, 76-87. doi:10.1016/j.quageo.2016.01.004
+#'
+#' \bold{Details} \cr
+#' \tabular{ll}{
+#' Lab: \tab University of Lausanne \cr
+#' Lab-Code: \tab UNIL/NB123 \cr
+#' Location: \tab Namche Barwa (eastern Himalaya)\cr
+#' Material: \tab Coarse grained (180-212 microns) potassium feldspar \cr
+#' Units: \tab Values are given in seconds \cr
+#' Lab Dose Rate: \tab Dose rate of the beta-source at measurement ca. 0.1335 +/-
+#' 0.004 Gy/s \cr
+#' Environmental Dose Rate: \tab 7.00 +/- 0.92 Gy/ka (includes internal dose rate)
+#' }
+#'
+#'
+#' @keywords datasets
+#'
+#' @examples
+#'
+#' ## Load example data
+#' data("ExampleData.Fading", envir = environment())
+#'
+#' ## Get fading measurement data of the IR50 signal
+#' IR50_fading <- ExampleData.Fading$fading.data$IR50
+#' head(IR50_fading)
+#'
+#' ## Determine g-value and rho' for the IR50 signal
+#' IR50_fading.res <- analyse_FadingMeasurement(IR50_fading)
+#'
+#' ## Show g-value and rho' results
+#' gval <- get_RLum(IR50_fading.res)
+#' rhop <- get_RLum(IR50_fading.res, "rho_prime")
+#'
+#' gval
+#' rhop
+#'
+#' ## Get LxTx values of the IR50 DE measurement
+#' IR50_De.LxTx <- ExampleData.Fading$equivalentDose.data$IR50
+#'
+#' ## Calculate the De of the IR50 signal
+#' IR50_De <- plot_GrowthCurve(IR50_De.LxTx,
+#'                                 mode = "regenerative",
+#'                                 fit.method = "EXP")
+#'
+#' ## Extract the calculated De and its error
+#' IR50_De.res <- get_RLum(IR50_De)
+#' De <- c(IR50_De.res$De, IR50_De.res$De.Error)
+#'
+#' ## Apply fading correction (age conversion greatly simplified)
+#' IR50_Age <- De / 7.00
+#' IR50_Age.corr <- calc_FadingCorr(IR50_Age, g_value = IR50_fading.res)
+#'
+#'
+#' @name ExampleData.Fading
+NULL
