@@ -38,9 +38,6 @@
 #' data sets must be provided as \code{list}, e.g. \code{list(data.1, data.2)}.
 #' @param na.rm \code{\link{logical}} (with default): excludes \code{NA}
 #' values from the data set prior to any further operations.
-#' @param negatives \code{\link{character}} (with default): rule for negative
-#' values. Default is \code{"remove"} (i.e. negative values are removed from
-#' the data set).
 #' @param log.z \code{\link{logical}} (with default): Option to display the
 #' z-axis in logarithmic scale. Default is \code{TRUE}.
 #' @param central.value \code{\link{numeric}}: User-defined central value,
@@ -180,7 +177,7 @@
 #'                 xlab = c("Data error (%)",
 #'                          "Data precision"),
 #'                 ylab = "Scatter",
-#'                 zlab = "Equivalent dose (Gy)")
+#'                 zlab = "Equivalent dose [Gy]")
 #'
 #' ## now with minimum, maximum and median value indicated
 #' plot_RadialPlot(data = ExampleData.DeValues,
@@ -219,7 +216,6 @@
 plot_RadialPlot <- function(
   data,
   na.rm = TRUE,
-  negatives = "remove",
   log.z = TRUE,
   central.value,
   centrality = "mean.weighted",
@@ -265,11 +261,25 @@ plot_RadialPlot <- function(
   if(missing(summary.pos) == TRUE) {
     summary.pos <- "sub"
   }
-  if(missing(bar.col) == TRUE) {bar.col <- rep("grey80", length(data))}
-  if(missing(grid.col) == TRUE) {grid.col <- rep("grey70", length(data))}
-  if(missing(summary) == TRUE) {summary <- NULL}
-  if(missing(summary.pos) == TRUE) {summary.pos <- "topleft"}
-  if(missing(mtext) == TRUE) {mtext <- ""}
+  if(missing(bar.col) == TRUE) {
+    bar.col <- rep("grey80", length(data))
+  }
+  
+  if(missing(grid.col) == TRUE) {
+    grid.col <- rep("grey70", length(data))
+  }
+  
+  if(missing(summary) == TRUE) {
+    summary <- NULL
+  }
+  
+  if(missing(summary.pos) == TRUE) {
+    summary.pos <- "topleft"
+  }
+  
+  if(missing(mtext) == TRUE) {
+    mtext <- ""
+  }
 
 
   ## check z-axis log-option for grouped data sets
@@ -300,42 +310,47 @@ plot_RadialPlot <- function(
   } else {
     z.span <- (mean(De.global) * 0.5) / (sd(De.global) * 100)
     z.span <- ifelse(z.span > 1, 0.9, z.span)
-    limits.z <- c((ifelse(min(De.global) <= 0, 1.1, 0.9) - z.span) * min(De.global),
+    limits.z <- c((ifelse(test = min(De.global) <= 0, 
+                          yes = 1.1,
+                          no =  0.9) - z.span) * min(De.global),
                   (1.1 + z.span) * max(De.global))
   }
 
   ticks <- round(pretty(limits.z, n = 5), 3)
   De.delta <- ticks[2] - ticks[1]
 
-#   ## calculate correction dose to shift negative values
-#   if(min(De.global) <= 0) {
-#     De.add <- abs(ticks[length(ticks) - sum(ticks > limits.z[1])])
-#   } else {De.add <- 0}
-
-  ## optionally, reassign De.add to remove negative values
-  if(negatives == "remove") {
-    De.add <- 0
-
-    for(i in 1:length(data)) {
-      data.test <- data[[i]][,1] <= 0
-      data[[i]] <- data[[i]][!data.test,]
-      data.negative <- paste(seq(1, length(data.test))[data.test == TRUE],
-                             collapse = ", ")
-      if(sum(data.test) > 0) {
-        warning(paste("The following lines contain zero or negative values: ",
-                      data.negative,
-                      ".",
-                      sep = ""))
+  ## calculate correction dose to shift negative values
+  if(min(De.global) <= 0) {
+    
+    if("zlim" %in% names(extraArgs)) {
+      
+      De.add <- abs(extraArgs$zlim[1])
+    } else {
+    
+      ## estimate delta De to add to all data
+      De.add <-  min(10^ceiling(log10(abs(De.global))) * 10)
+      
+      ## optionally readjust delta De for extreme values
+      if(De.add <= abs(min(De.global))) {
+        
+        De.add <- De.add * 10
       }
     }
+  } else {
+    De.add <- 0
   }
 
   ## optionally add correction dose to data set and adjust error
-  for(i in 1:length(data)) {
-    data[[i]][,1] <- data[[i]][,1] + De.add
-    data[[i]][,2] <- data[[i]][,2] * data[[i]][,1] / abs(data[[i]][,1] - De.add)
+  if(log.z == TRUE) {
+    
+    for(i in 1:length(data)) {
+      data[[i]][,1] <- data[[i]][,1] + De.add
+    }
+    
+    De.global <- De.global + De.add
+    
   }
-
+  
   ## calculate major preliminary tick values and tick difference
   extraArgs <- list(...)
   if("zlim" %in% names(extraArgs)) {
@@ -349,23 +364,6 @@ plot_RadialPlot <- function(
   ticks <- round(pretty(limits.z, n = 5), 3)
   De.delta <- ticks[2] - ticks[1]
 
-  ## calculate correction dose to shift negative values
-  if(min(De.global) <= 0) {
-    De.add <- abs(ticks[length(ticks) - sum(ticks > limits.z[1])])
-  } else {De.add <- 0}
-
-  if(negatives == "remove") {
-    De.add <- 0
-  }
-  ## optionally add correction dose to data set and adjust error
-  for(i in 1:length(data)) {
-    data[[i]][,1] <- data[[i]][,1] + De.add
-    data[[i]][,2] <- data[[i]][,2] * data[[i]][,1] / abs(data[[i]][,1] - De.add)
-  }
-
-  ## adjust limits.z
-  limits.z <- limits.z + 2 * De.add
-
   ## calculate and append statistical measures --------------------------------
 
   ## z-values based on log-option
@@ -377,8 +375,17 @@ plot_RadialPlot <- function(
   rm(z)
 
   ## calculate se-values based on log-option
-  se <- sapply(1:length(data), function(x){
-    if(log.z == TRUE) {data[[x]][,2] / data[[x]][,1]} else {data[[x]][,2]}})
+  se <- sapply(1:length(data), function(x, De.add){
+    if(log.z == TRUE) {
+      
+      if(De.add != 0) {
+        data[[x]][,2] <- data[[x]][,2] / (data[[x]][,1] + De.add)
+      } else {
+        data[[x]][,2] / data[[x]][,1]
+      }
+    } else {
+      data[[x]][,2]
+    }}, De.add = De.add)
   if(is(se, "list") == FALSE) {se <- list(se)}
   data <- lapply(1:length(data), function(x) {
     cbind(data[[x]], se[[x]])})
@@ -420,9 +427,9 @@ plot_RadialPlot <- function(
   } else if(is.numeric(centrality) == TRUE &
               length(centrality) == length(data)) {
     z.central.raw <- if(log.z == TRUE) {
-      log(centrality)
+      log(centrality + De.add)
     } else {
-      centrality
+      centrality + De.add
     }
     z.central <- lapply(1:length(data), function(x){
       rep(z.central.raw[x], length(data[[x]][,3]))})
@@ -522,11 +529,12 @@ if(centrality[1] == "mean") {
   ## optionally adjust zentral value by user-defined value
   if(missing(central.value) == FALSE) {
 
-    ## adjust central value for De.add
-    central.value <- central.value + 2 * De.add
+    # ## adjust central value for De.add
+    central.value <- central.value + De.add
 
     z.central.global <- ifelse(log.z == TRUE,
-                               log(central.value), central.value)
+                               log(central.value), 
+                               central.value)
   }
 
   ## create column names
@@ -591,7 +599,7 @@ if(centrality[1] == "mean") {
   zlab <- if("zlab" %in% names(extraArgs)) {
     extraArgs$zlab
     } else {
-      expression(paste(D[e], " (Gy)"))
+      expression(paste(D[e], " [Gy]"))
     }
 
   if("zlim" %in% names(extraArgs)) {
@@ -602,9 +610,6 @@ if(centrality[1] == "mean") {
     limits.z <- c((0.9 - z.span) * min(data.global[[1]]),
                   (1.1 + z.span) * max(data.global[[1]]))
   }
-  if(limits.z[1] <= 0) {
-    limits.z <- limits.z + 2 * De.add
-  }
 
   if("xlim" %in% names(extraArgs)) {
     limits.x <- extraArgs$xlim
@@ -718,7 +723,7 @@ if(centrality[1] == "mean") {
   }
 
   ## calculate z-axis radius
-  r.x <- limits.x[2] / max(data.global[,6]) + 0.03
+  r.x <- limits.x[2] / max(data.global[,6]) + 0.05
   r <- max(sqrt((data.global[,6])^2+(data.global[,7] * f)^2)) * r.x
 
   ## calculate major z-tick coordinates
@@ -759,7 +764,7 @@ if(centrality[1] == "mean") {
 
   ## subtract De.add from label values
   if(De.add != 0) {
-    label.z.text <- label.z.text - 2 * De.add
+    label.z.text <- label.z.text - De.add
   }
 
   labels <- cbind(label.x, label.y, label.z.text)
@@ -779,6 +784,7 @@ if(centrality[1] == "mean") {
                          (data[[i]][1,5] - z.central.global) *
                            polygons[i,4] - 2)
   }
+  
   ## calculate node coordinates for semi-circle
   user.limits <- if(log.z == TRUE) {
     log(limits.z)
@@ -797,11 +803,25 @@ if(centrality[1] == "mean") {
   ellipse.y <- (ellipse.values - z.central.global) * ellipse.x
   ellipse <- cbind(ellipse.x, ellipse.y)
   ellipse.lims <- rbind(range(ellipse[,1]), range(ellipse[,2]))
+  
+  ## check if z-axis overlaps with 2s-polygon
+  polygon_y_max <- max(polygons[,7])
+  polygon_y_min <- min(polygons[,7])
+  
+  z_2s_upper <- ellipse.x[abs(ellipse.y - polygon_y_max) == 
+                            min(abs(ellipse.y - polygon_y_max))]
+  
+  z_2s_lower <- ellipse.x[abs(ellipse.y - polygon_y_min) == 
+                            min(abs(ellipse.y - polygon_y_min))]
+
+  if(max(polygons[,3]) >= z_2s_upper | max(polygons[,3]) >= z_2s_lower) {
+    print("[plot_RadialPlot] Warning: z-scale touches 2s-polygon. Decrease plot ratio.")
+  }
 
   ## calculate statistical labels
   if(length(stats == 1)) {stats <- rep(stats, 2)}
   stats.data <- matrix(nrow = 3, ncol = 3)
-  data.stats <- as.numeric(data.global[,1] - 2 * De.add)
+  data.stats <- as.numeric(data.global[,1])
 
   if("min" %in% stats == TRUE) {
     stats.data[1, 3] <- data.stats[data.stats == min(data.stats)][1]
@@ -831,7 +851,6 @@ if(centrality[1] == "mean") {
     if(limits.z.y[2] > 0.77 * limits.y[2]) {
       limits.y[2] <- 1.3 * limits.z.y[2]
     }
-#    limits.y <- c(-max(abs(limits.y)), max(abs(limits.y)))
   }
   if(!("xlim" %in% names(extraArgs))) {
     if(limits.z.x[2] > 1.1 * limits.x[2]) {
@@ -861,7 +880,9 @@ if(centrality[1] == "mean") {
                           "se.rel.weighted")
 
   for(i in 1:length(data)) {
-    statistics <- calc_Statistics(data[[i]])
+    data_to_stats <- data[[i]]
+    data_to_stats$De <- data_to_stats$De - De.add
+    statistics <- calc_Statistics(data = data_to_stats)
     De.stats[i,1] <- statistics$weighted$n
     De.stats[i,2] <- statistics$unweighted$mean
     De.stats[i,3] <- statistics$weighted$mean
@@ -1223,6 +1244,9 @@ label.text[[1]] <- NULL
 
   ## calculate line coordinates and further parameters
   if(missing(line) == FALSE) {
+    
+    line = line + De.add
+    
     if(log.z == TRUE) {line <- log(line)}
 
     line.coords <- list(NA)
